#
# spec file for package kf6-kiconthemes
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kiconthemes
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kiconthemes
Version:        6.10.0
Release:        1.2
Summary:        Icon GUI utilities
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6BreezeIcons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ColorScheme) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6ItemViews) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6UiPlugin) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}

%description
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks.

%package imports
Summary:        QML Imports for kiconthemes

%description imports
QML Bindings for the kiconthemes framework.

%package -n libKF6IconThemes6
Summary:        Icon GUI utilities
Requires:       kf6-kiconthemes >= %{version}
Recommends:     breeze6-icons

%description -n libKF6IconThemes6
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks.

%package -n libKF6IconWidgets6
Summary:        Icon GUI utilities
Requires:       kf6-kiconthemes >= %{version}
Recommends:     breeze6-icons

%description -n libKF6IconWidgets6
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks.

%package devel
Summary:        Icon GUI utilities: Build Environment
Requires:       libKF6IconThemes6 = %{version}
Requires:       libKF6IconWidgets6 = %{version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}

%description devel
This library contains classes to improve the handling of icons
in applications using the KDE Frameworks. Development files.

%lang_package -n libKF6IconThemes6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kiconthemes6

%ldconfig_scriptlets -n libKF6IconThemes6
%ldconfig_scriptlets -n libKF6IconWidgets6

%files
%{_kf6_debugdir}/kiconthemes.categories
%{_kf6_debugdir}/kiconthemes.renamecategories
%dir %{_kf6_plugindir}/kiconthemes6/
%dir %{_kf6_plugindir}/kiconthemes6/iconengines
%{_kf6_plugindir}/kiconthemes6/iconengines/KIconEnginePlugin.so

%files imports
%{_kf6_qmldir}/org/kde/iconthemes/

%files -n libKF6IconThemes6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6IconThemes.so.*

%files -n libKF6IconWidgets6
%{_kf6_libdir}/libKF6IconWidgets.so.*

%files devel
%doc %{_kf6_qchdir}/KF6IconThemes.*
%doc %{_kf6_qchdir}/KF6IconWidgets.*
%{_kf6_bindir}/kiconfinder6
%{_kf6_cmakedir}/KF6IconThemes/
%{_kf6_includedir}/KIconThemes/
%{_kf6_includedir}/KIconWidgets/
%{_kf6_libdir}/libKF6IconThemes.so
%{_kf6_libdir}/libKF6IconWidgets.so
%{_kf6_plugindir}/designer/kiconthemes6widgets.so

%files -n libKF6IconThemes6-lang -f kiconthemes6.lang

%changelog
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * use Qt API to fully override the engine
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * Now we depend against qt6.6.0
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Port to KStandardActions
  * Postpone spawning KColorSchemeManager instance
  * Add CI for static builds on Linux
  * Init mimeType icons on demand
  * Update version to 6.8.0
  * Set up KColorSchemeManager on Android as well
  * Reduce temporary allocations
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Allow building without breeze-icons
  * extend initTheme to ensure we properly follow the system colors
  * Add path for Android to theme locations
  * Take logical pixels in KIconEngine::createPixmap
  * [kiconengine] Adapt to Qt behavior change in scaledPixmap (kde#491677)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * fix icon recoloring for portable installers
  * Overhaul KIconEngine docs
  * Deprecate KIconLoader::drawOverlays
  * Deprecate movie loading API
  * Add back effect into cache key (kde#490795)
  * Deprecate KIconEffect::apply API
  * Refactor icon effect application
  * [kiconeffect] Add static API for active effect
  * [kiconeffect] Add static API for disabled effect
  * [kiconeffects] Drop color and color2 members
  * [kiconeffects] Don't read effect settings from kconfig
  * [kiconeffect] Replace raw numbers with relevant enum
  * Add note to prefer QIcon::fromTheme over KIconLoader
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Flip logic when to use Accent/HighlightedText
  * support USE_DBUS option to enable/disable dbus use
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Add missing include
  * KIconDialog: Prevent briefly visible mini-window from showing up (kde#487762)
  * Update file kicontheme.cpp
  * include only if needed, avoid extra define
  * Set QML module base version to 1.0
  * Windows tests work now
  * use Qt to fill in the generic mime-type icon information
  * use Qt to fill in the generic mime-type icon information
  * ensure tests pass locally with KDE platform theme, too
  * ensure we not clash with breeze from resource
  * adapt test to fact we now have Breeze with hicolor inherits
  * remove not used files
  * remove my old rcc test, no longer done
  * always require the icon library
  * Add KIconTheme::initTheme() to configure proper icon set as opt-in
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * allow to configure if we register our icon plugin for SVGs
  * Port QML module to declarative type registration
  * Fix typo in BreezeIcons::initIcons loading
  * gitignore: add VS Code dir
  * Set QML module base version to 1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * fix dbus disabling
  * don't hang if no session bus is around
  * Don't search for QtDBus on Windows/macOS
  * Eliminate a frequent "Invalid Context" warning for FileSystems
  * KIconDialog: Add filter for symbolic icons
  * Allow creating KIconEngine with colors and overlays
  * Add breeze-icons dependency
  * Mark index.theme config as SimpleConfig
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * Mark index.theme config as SimpleConfig
  * update version for new release
  * Remove unused member
  * Expose accent color in KIConColors
  * [kiconloader] Set devicePixelRatio for pixmap before storing it in cache
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kiconthemes
